﻿/**
* Sample code for the GetNonContractShipments Canada Post service.
* 
* The GetNonContractShipments service invokes a search for previously created 
* shipments. It is used to recover from communication failures or hardcopy print 
* failures.  
*
* This sample is configured to access the Developer Program sandbox environment. 
* Use your development key username and password for the web service credentials.
* 
**/

using System;
using System.ServiceModel.Channels;
using System.ServiceModel;
using System.Configuration;
using System.Security.Authentication;
using System.Net;

namespace GetNCShipments
{
    class GetNCShipments
    {
        //TLS 1.2 support for .NET 3.5
        public const SslProtocols _Tls12 = (SslProtocols)0x00000C00;
        public const SecurityProtocolType Tls12 = (SecurityProtocolType)_Tls12;

        static void Main(string[] args)
        {
            ServicePointManager.SecurityProtocol = Tls12;

            // Your username, password and customer number are imported from the following file
            // CPCWS_SOAP_NCShipping_DotNet_Samples\SOAP\ncshipping\user.xml 
            var username = ConfigurationSettings.AppSettings["username"];
            var password = ConfigurationSettings.AppSettings["password"];
            var mailedBy = ConfigurationSettings.AppSettings["customerNumber"];

            NCShipmentPortTypeClient server = new NCShipmentPortTypeClient("NCShipmentPort", "https://ct.soa-gw.canadapost.ca/rs/soap/ncshipment/v4");
            server.ClientCredentials.UserName.UserName = username;
            server.ClientCredentials.UserName.Password = password;

            // Create Request
            getnoncontractshipmentsrequest request = new getnoncontractshipmentsrequest();
            request.locale = "FR";
            request.mailedby = mailedBy;
            request.from = new DateTime(2011, 1, 1, 0, 0, 0);
            request.toSpecified = true;
            request.to = new DateTime(2012, 2, 1, 0, 0, 0);

            // Disable timestamp on request
            BindingElementCollection elements = server.Endpoint.Binding.CreateBindingElements();
            elements.Find<SecurityBindingElement>().IncludeTimestamp = false;
            server.Endpoint.Binding = new CustomBinding(elements);

            String responseAsString = "";

            try
            {
                // Execute Request
                getnoncontractshipmentsresponse response = server.GetNCShipments(request);

                // Retrieve values from response object
                if (response.Item.GetType() == typeof(NonContractShipmentsType))
                {
                    NonContractShipmentsType shipments = (NonContractShipmentsType)response.Item;
                    if (shipments.shipmentid != null)
                    {
                        foreach (var shipmentId in shipments.shipmentid)
                        {
                            responseAsString += "Shipment Id: " + shipmentId + "\r\n";
                        }
                    }
                    else
                    {
                        responseAsString += "No shipments returned.\r\n";
                    }
                }
                else
                {
                    messages msgs = (messages)response.Item;
                    foreach (var item in msgs.message)
                    {
                        responseAsString += "Error Code: " + item.code + "\r\n";
                        responseAsString += "Error Msg: " + item.description + "\r\n";
                    }
                }
            }
            catch (FaultException faultEx)
            {
                // SOAP Fault
                responseAsString += "Fault Code: " + faultEx.Code.Name + "\r\n";
                responseAsString += "Fault String: " + faultEx.Message + "\r\n";
            }
            catch (Exception ex)
            {
                // Misc Exception
                responseAsString += "ERROR: " + ex.Message + "\r\n";
            }

            Console.WriteLine(responseAsString);
            Console.WriteLine("Press any key to continue...");
            Console.ReadKey(true);

        }
    }
}
